@@ -1,7 +1,7 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 /* exported Dialog, MessageDialogContent, ListSection, ListSectionItem */
 
-const { Clutter, GObject, Meta, Pango, St } = imports.gi;
+const { Clutter, GLib, GObject, Meta, Pango, St } = imports.gi;
 
 function _setLabel(label, value) {
     label.set({
@@ -221,13 +221,16 @@ var MessageDialogContent = GObject.registerClass({
             this._updateTitleStyleLater = Meta.later_add(Meta.LaterType.BEFORE_REDRAW, () => {
                 this._updateTitleStyleLater = 0;
                 this._title.add_style_class_name('leightweight');
-                return false;
+                return GLib.SOURCE_REMOVE;
             });
         }
 
     }
 
     set title(title) {
+        if (this._title.text === title)
+            return;
+
         _setLabel(this._title, title);
 
         this._title.remove_style_class_name('leightweight');
@@ -237,6 +240,9 @@ var MessageDialogContent = GObject.registerClass({
     }
 
     set description(description) {
+        if (this._description.text === description)
+            return;
+
         _setLabel(this._description, description);
         this.notify('description');
     }
