@@ -43,9 +43,6 @@ struct _StBinPrivate
 {
   ClutterActor *child;
 
-  StAlign       x_align;
-  StAlign       y_align;
-
   guint         x_fill : 1;
   guint         y_fill : 1;
 };
@@ -55,12 +52,14 @@ enum
   PROP_0,
 
   PROP_CHILD,
-  PROP_X_ALIGN,
-  PROP_Y_ALIGN,
   PROP_X_FILL,
-  PROP_Y_FILL
+  PROP_Y_FILL,
+
+  N_PROPS
 };
 
+static GParamSpec *props[N_PROPS] = { NULL, };
+
 static void clutter_container_iface_init (ClutterContainerIface *iface);
 
 G_DEFINE_TYPE_WITH_CODE (StBin, st_bin, ST_TYPE_WIDGET,
@@ -93,6 +92,27 @@ clutter_container_iface_init (ClutterContainerIface *iface)
   iface->remove = st_bin_remove;
 }
 
+static double
+get_align_factor (ClutterActorAlign align)
+{
+  switch (align)
+    {
+    case CLUTTER_ACTOR_ALIGN_CENTER:
+      return 0.5;
+
+    case CLUTTER_ACTOR_ALIGN_START:
+      return 0.0;
+
+    case CLUTTER_ACTOR_ALIGN_END:
+      return 1.0;
+
+    case CLUTTER_ACTOR_ALIGN_FILL:
+      break;
+   }
+
+  return 0.0;
+}
+
 static void
 st_bin_allocate (ClutterActor          *self,
                  const ClutterActorBox *box,
@@ -105,15 +125,16 @@ st_bin_allocate (ClutterActor          *self,
   if (priv->child && clutter_actor_is_visible (priv->child))
     {
       StThemeNode *theme_node = st_widget_get_theme_node (ST_WIDGET (self));
+      ClutterActorAlign x_align = clutter_actor_get_x_align (priv->child);
+      ClutterActorAlign y_align = clutter_actor_get_y_align (priv->child);
       ClutterActorBox childbox;
-      gdouble x_align_f, y_align_f;
 
       st_theme_node_get_content_box (theme_node, box, &childbox);
-      st_get_align_factors (priv->x_align, priv->y_align,
-                            &x_align_f, &y_align_f);
       clutter_actor_allocate_align_fill (priv->child, &childbox,
-                                         x_align_f, y_align_f,
-                                         priv->x_fill, priv->y_fill,
+                                         get_align_factor (x_align),
+                                         get_align_factor (y_align),
+                                         x_align == CLUTTER_ACTOR_ALIGN_FILL,
+                                         y_align == CLUTTER_ACTOR_ALIGN_FILL,
                                          flags);
     }
 }
@@ -139,7 +160,10 @@ st_bin_get_preferred_width (ClutterActor *self,
     }
   else
     {
-      _st_actor_get_preferred_width (priv->child, for_height, priv->y_fill,
+      ClutterActorAlign y_align = clutter_actor_get_y_align (priv->child);
+
+      _st_actor_get_preferred_width (priv->child, for_height,
+                                     y_align == CLUTTER_ACTOR_ALIGN_FILL,
                                      min_width_p,
                                      natural_width_p);
     }
@@ -168,7 +192,10 @@ st_bin_get_preferred_height (ClutterActor *self,
     }
   else
     {
-      _st_actor_get_preferred_height (priv->child, for_width, priv->x_fill,
+      ClutterActorAlign x_align = clutter_actor_get_y_align (priv->child);
+
+      _st_actor_get_preferred_height (priv->child, for_width,
+                                      x_align == CLUTTER_ACTOR_ALIGN_FILL,
                                       min_height_p,
                                       natural_height_p);
     }
@@ -241,18 +268,6 @@ st_bin_set_property (GObject      *gobject,
       st_bin_set_child (bin, g_value_get_object (value));
       break;
 
-    case PROP_X_ALIGN:
-      st_bin_set_alignment (bin,
-                            g_value_get_enum (value),
-                            priv->y_align);
-      break;
-
-    case PROP_Y_ALIGN:
-      st_bin_set_alignment (bin,
-                            priv->x_align,
-                            g_value_get_enum (value));
-      break;
-
     case PROP_X_FILL:
       st_bin_set_fill (bin,
                        g_value_get_boolean (value),
@@ -292,14 +307,6 @@ st_bin_get_property (GObject    *gobject,
       g_value_set_boolean (value, priv->y_fill);
       break;
 
-    case PROP_X_ALIGN:
-      g_value_set_enum (value, priv->x_align);
-      break;
-
-    case PROP_Y_ALIGN:
-      g_value_set_enum (value, priv->y_align);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
     }
@@ -311,7 +318,6 @@ st_bin_class_init (StBinClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   ClutterActorClass *actor_class = CLUTTER_ACTOR_CLASS (klass);
   StWidgetClass *widget_class = ST_WIDGET_CLASS (klass);
-  GParamSpec *pspec;
 
   gobject_class->set_property = st_bin_set_property;
   gobject_class->get_property = st_bin_get_property;
@@ -329,73 +335,45 @@ st_bin_class_init (StBinClass *klass)
    *
    * The child #ClutterActor of the #StBin container.
    */
-  pspec = g_param_spec_object ("child",
-                               "Child",
-                               "The child of the Bin",
-                               CLUTTER_TYPE_ACTOR,
-                               ST_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_CHILD, pspec);
-
-  /**
-   * StBin:x-align:
-   *
-   * The horizontal alignment of the #StBin child.
-   */
-  pspec = g_param_spec_enum ("x-align",
-                             "X Align",
-                             "The horizontal alignment",
-                             ST_TYPE_ALIGN,
-                             ST_ALIGN_MIDDLE,
-                             ST_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_X_ALIGN, pspec);
-
-  /**
-   * StBin:y-align:
-   *
-   * The vertical alignment of the #StBin child.
-   */
-  pspec = g_param_spec_enum ("y-align",
-                             "Y Align",
-                             "The vertical alignment",
-                             ST_TYPE_ALIGN,
-                             ST_ALIGN_MIDDLE,
-                             ST_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_Y_ALIGN, pspec);
+  props[PROP_CHILD] =
+    g_param_spec_object ("child",
+                         "Child",
+                         "The child of the Bin",
+                         CLUTTER_TYPE_ACTOR,
+                         ST_PARAM_READWRITE);
 
   /**
    * StBin:x-fill:
    *
    * Whether the child should fill the horizontal allocation
    */
-  pspec = g_param_spec_boolean ("x-fill",
-                                "X Fill",
-                                "Whether the child should fill the "
-                                "horizontal allocation",
-                                FALSE,
-                                ST_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_X_FILL, pspec);
+  props[PROP_X_FILL] =
+    g_param_spec_boolean ("x-fill",
+                          "X Fill",
+                          "Whether the child should fill the "
+                          "horizontal allocation",
+                          FALSE,
+                          ST_PARAM_READWRITE | G_PARAM_DEPRECATED);
 
   /**
    * StBin:y-fill:
    *
    * Whether the child should fill the vertical allocation
    */
-  pspec = g_param_spec_boolean ("y-fill",
-                                "Y Fill",
-                                "Whether the child should fill the "
-                                "vertical allocation",
-                                FALSE,
-                                ST_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_Y_FILL, pspec);
+  props[PROP_Y_FILL] =
+    g_param_spec_boolean ("y-fill",
+                          "Y Fill",
+                          "Whether the child should fill the "
+                          "vertical allocation",
+                          FALSE,
+                          ST_PARAM_READWRITE | G_PARAM_DEPRECATED);
+
+  g_object_class_install_properties (gobject_class, N_PROPS, props);
 }
 
 static void
 st_bin_init (StBin *bin)
 {
-  StBinPrivate *priv = st_bin_get_instance_private (bin);
-
-  priv->x_align = ST_ALIGN_MIDDLE;
-  priv->y_align = ST_ALIGN_MIDDLE;
 }
 
 /**
@@ -447,7 +425,7 @@ st_bin_set_child (StBin        *bin,
 
   clutter_actor_queue_relayout (CLUTTER_ACTOR (bin));
 
-  g_object_notify (G_OBJECT (bin), "child");
+  g_object_notify_by_pspec (G_OBJECT (bin), props[PROP_CHILD]);
 }
 
 /**
@@ -466,76 +444,6 @@ st_bin_get_child (StBin *bin)
   return ((StBinPrivate *)st_bin_get_instance_private (bin))->child;
 }
 
-/**
- * st_bin_set_alignment:
- * @bin: a #StBin
- * @x_align: horizontal alignment
- * @y_align: vertical alignment
- *
- * Sets the horizontal and vertical alignment of the child
- * inside a #StBin.
- */
-void
-st_bin_set_alignment (StBin  *bin,
-                      StAlign x_align,
-                      StAlign y_align)
-{
-  StBinPrivate *priv;
-  gboolean changed = FALSE;
-
-  g_return_if_fail (ST_IS_BIN (bin));
-
-  priv = st_bin_get_instance_private (bin);
-
-  g_object_freeze_notify (G_OBJECT (bin));
-
-  if (priv->x_align != x_align)
-    {
-      priv->x_align = x_align;
-      g_object_notify (G_OBJECT (bin), "x-align");
-      changed = TRUE;
-    }
-
-  if (priv->y_align != y_align)
-    {
-      priv->y_align = y_align;
-      g_object_notify (G_OBJECT (bin), "y-align");
-      changed = TRUE;
-    }
-
-  if (changed)
-    clutter_actor_queue_relayout (CLUTTER_ACTOR (bin));
-
-  g_object_thaw_notify (G_OBJECT (bin));
-}
-
-/**
- * st_bin_get_alignment:
- * @bin: a #StBin
- * @x_align: return location for the horizontal alignment, or %NULL
- * @y_align: return location for the vertical alignment, or %NULL
- *
- * Retrieves the horizontal and vertical alignment of the child
- * inside a #StBin, as set by st_bin_set_alignment().
- */
-void
-st_bin_get_alignment (StBin   *bin,
-                      StAlign *x_align,
-                      StAlign *y_align)
-{
-  StBinPrivate *priv;
-
-  g_return_if_fail (ST_IS_BIN (bin));
-
-  priv = st_bin_get_instance_private (bin);
-
-  if (x_align)
-    *x_align = priv->x_align;
-
-  if (y_align)
-    *y_align = priv->y_align;
-}
-
 /**
  * st_bin_set_fill:
  * @bin: a #StBin
@@ -551,7 +459,6 @@ st_bin_set_fill (StBin   *bin,
                  gboolean y_fill)
 {
   StBinPrivate *priv;
-  gboolean changed = FALSE;
 
   g_return_if_fail (ST_IS_BIN (bin));
 
@@ -562,22 +469,17 @@ st_bin_set_fill (StBin   *bin,
   if (priv->x_fill != x_fill)
     {
       priv->x_fill = x_fill;
-      changed = TRUE;
 
-      g_object_notify (G_OBJECT (bin), "x-fill");
+      g_object_notify_by_pspec (G_OBJECT (bin), props[PROP_X_FILL]);
     }
 
   if (priv->y_fill != y_fill)
     {
       priv->y_fill = y_fill;
-      changed = TRUE;
 
-      g_object_notify (G_OBJECT (bin), "y-fill");
+      g_object_notify_by_pspec (G_OBJECT (bin), props[PROP_Y_FILL]);
     }
 
-  if (changed)
-    clutter_actor_queue_relayout (CLUTTER_ACTOR (bin));
-
   g_object_thaw_notify (G_OBJECT (bin));
 }
 
